import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('invoke_workflow')
@click.argument("workflow_id", type=str)

@click.option(
    "--inputs",
    help="A mapping of workflow inputs to datasets and dataset collections. The datasets source can be a LibraryDatasetDatasetAssociation (``ldda``), LibraryDataset (``ld``), HistoryDatasetAssociation (``hda``), or HistoryDatasetCollectionAssociation (``hdca``).",
    type=str
)
@click.option(
    "--params",
    help="A mapping of non-datasets tool parameters (see below)",
    type=str
)
@click.option(
    "--history_id",
    help="The encoded history ID where to store the workflow output. Alternatively, ``history_name`` may be specified to create a new history.",
    type=str
)
@click.option(
    "--history_name",
    help="Create a new history with the given name to store the workflow output. If both ``history_id`` and ``history_name`` are provided, ``history_name`` is ignored. If neither is specified, a new 'Unnamed history' is created.",
    type=str
)
@click.option(
    "--import_inputs_to_history",
    help="If ``True``, used workflow inputs will be imported into the history. If ``False``, only workflow outputs will be visible in the given history.",
    is_flag=True
)
@click.option(
    "--replacement_params",
    help="pattern-based replacements for post-job actions (see below)",
    type=str
)
@click.option(
    "--allow_tool_state_corrections",
    help="If True, allow Galaxy to fill in missing tool state when running workflows. This may be useful for workflows using tools that have changed over time or for workflows built outside of Galaxy with only a subset of inputs defined.",
    is_flag=True
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, workflow_id, inputs="", params="", history_id="", history_name="", import_inputs_to_history=False, replacement_params="", allow_tool_state_corrections=""):
    """Invoke the workflow identified by ``workflow_id``. This will cause a workflow to be scheduled and return an object describing the workflow invocation.
    """
    return ctx.gi.workflows.invoke_workflow(workflow_id, inputs=inputs, params=params, history_id=history_id, history_name=history_name, import_inputs_to_history=import_inputs_to_history, replacement_params=replacement_params, allow_tool_state_corrections=allow_tool_state_corrections)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('get_state')
@click.argument("job_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, job_id):
    """Display the current state for a given job of the current user.
    """
    return ctx.gi.jobs.get_state(job_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('create_user_apikey')
@click.argument("user_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, user_id):
    """Create a new API key for a given user.
    """
    return ctx.gi.users.create_user_apikey(user_id)



import click
from parsec.commands.config.get_config import cli as func0
from parsec.commands.config.get_version import cli as func1

@click.group()
def cli():
	pass

cli.add_command(func0)
cli.add_command(func1)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('upload_file_contents')
@click.argument("library_id", type=str)
@click.argument("pasted_content", type=str)

@click.option(
    "--folder_id",
    help="id of the folder where to place the uploaded file. If not provided, the root folder will be used",
    type=str
)
@click.option(
    "--file_type",
    help="Galaxy file format name",
    default="auto",
    type=str
)
@click.option(
    "--dbkey",
    help="Dbkey",
    default="?",
    type=str
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, library_id, pasted_content, folder_id="", file_type="auto", dbkey="?"):
    """Upload pasted_content to a data library as a new file.
    """
    return ctx.gi.libraries.upload_file_contents(library_id, pasted_content, folder_id=folder_id, file_type=file_type, dbkey=dbkey)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('run_workflow')
@click.argument("workflow_id", type=str)

@click.option(
    "--dataset_map",
    help="A mapping of workflow inputs to datasets. The datasets source can be a LibraryDatasetDatasetAssociation (``ldda``), LibraryDataset (``ld``), or HistoryDatasetAssociation (``hda``). The map must be in the following format: ``{'<input>': {'id': <encoded dataset ID>, 'src': '[ldda, ld, hda]'}}`` (e.g. ``{'23': {'id': '29beef4fadeed09f', 'src': 'ld'}}``)",
    type=str
)
@click.option(
    "--params",
    help="A mapping of non-datasets tool parameters (see below)",
    type=str
)
@click.option(
    "--history_id",
    help="The encoded history ID where to store the workflow output. Alternatively, ``history_name`` may be specified to create a new history.",
    type=str
)
@click.option(
    "--history_name",
    help="Create a new history with the given name to store the workflow output. If both ``history_id`` and ``history_name`` are provided, ``history_name`` is ignored. If neither is specified, a new 'Unnamed history' is created.",
    type=str
)
@click.option(
    "--import_inputs_to_history",
    help="If ``True``, used workflow inputs will be imported into the history. If ``False``, only workflow outputs will be visible in the given history.",
    is_flag=True
)
@click.option(
    "--replacement_params",
    help="pattern-based replacements for post-job actions (see below)",
    type=str
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, workflow_id, dataset_map="", params="", history_id="", history_name="", import_inputs_to_history=False, replacement_params=""):
    """Run the workflow identified by ``workflow_id``.
    """
    return ctx.gi.workflows.run_workflow(workflow_id, dataset_map=dataset_map, params=params, history_id=history_id, history_name=history_name, import_inputs_to_history=import_inputs_to_history, replacement_params=replacement_params)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('get_ftp_files')

@click.option(
    "--deleted",
    help=""
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, deleted=False):
    """Get a list of local files.
    """
    return ctx.gi.ftpfiles.get_ftp_files(deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('import_workflow_from_local_path')
@click.argument("file_local_path", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, file_local_path):
    """Imports a new workflow given the path to a file containing a previously exported workflow.
    """
    return ctx.gi.workflows.import_workflow_from_local_path(file_local_path)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('show_visualization')
@click.argument("visual_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, visual_id):
    """Get details of a given visualization.
    """
    return ctx.gi.visual.show_visualization(visual_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('delete_group_user')
@click.argument("group_id", type=str)
@click.argument("user_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, group_id, user_id):
    """Remove a user from the given group.
    """
    return ctx.gi.groups.delete_group_user(group_id, user_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('show_job')
@click.argument("job_id", type=str)

@click.option(
    "--full_details",
    help="when ``True``, the complete list of details for the given job.",
    is_flag=True
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, job_id, full_details=False):
    """Get details of a given job of the current user.
    """
    return ctx.gi.jobs.show_job(job_id, full_details=full_details)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('get_datatypes')

@click.option(
    "--extension_only",
    help=""
)
@click.option(
    "--upload_only",
    help=""
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, extension_only=False, upload_only=False):
    """Get the list of all installed datatypes.
    """
    return ctx.gi.datatypes.get_datatypes(extension_only=extension_only, upload_only=upload_only)



import click
from parsec.commands.datatypes.get_datatypes import cli as func0
from parsec.commands.datatypes.get_sniffers import cli as func1

@click.group()
def cli():
	pass

cli.add_command(func0)
cli.add_command(func1)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('get_quotas')

@click.option(
    "--deleted",
    help="Only return quota(s) that have been deleted",
    is_flag=True
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, deleted=False):
    """Get a list of quotas
    """
    return ctx.gi.quotas.get_quotas(deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('create_group')
@click.argument("group_name", type=str)

@click.option(
    "--user_ids",
    help="A list of encoded user IDs to add to the new group",
    type=str,
    multiple=True
)
@click.option(
    "--role_ids",
    help="A list of encoded role IDs to add to the new group",
    type=str,
    multiple=True
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, group_name, user_ids=None, role_ids=None):
    """Create a new group.
    """
    return ctx.gi.groups.create_group(group_name, user_ids=user_ids, role_ids=role_ids)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('show_quota')
@click.argument("quota_id", type=str)

@click.option(
    "--deleted",
    help="Search for quota in list of ones already marked as deleted",
    is_flag=True
)

@pass_context
@bioblend_exception
@dict_output
def cli(ctx, quota_id, deleted=False):
    """Display information on a quota
    """
    return ctx.gi.quotas.show_quota(quota_id, deleted=deleted)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('delete_dataset_collection')
@click.argument("history_id", type=str)
@click.argument("dataset_collection_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, history_id, dataset_collection_id):
    """Mark corresponding dataset collection as deleted.
    """
    return ctx.gi.histories.delete_dataset_collection(history_id, dataset_collection_id)



import os

import click

from bioblend import galaxy
from parsec.cli import pass_context
from parsec import config
from parsec.io import warn, info

CONFIG_TEMPLATE = """## Parsec Global Configuration File.
# Each stanza should contian a single galaxy server to control.
#
# You can set the key __default to the name of a default instance
__default: local

local:
    key: "%(key)s"
    url: "%(url)s"
    # email: ""
    # password: ""
"""

SUCCESS_MESSAGE = (
    "Ready to go! Type `parsec` to get a list of commands you can execute."
)


@click.command("config_init")
@pass_context
def cli(ctx, url=None, api_key=None, admin=False, **kwds):
    """Help initialize global configuration (in home directory)
    """
    # TODO: prompt for values someday.
    click.echo("""
Welcome to
      ____   ____ _   _____   _____  ___   _____
     / __ \ / __ `/  / ___/  / ___/ / _ \ / ___/
    / /_/ // /_/ /  / /     (__  ) /  __// /__
   / .___/ \__,_/  /_/     /____/  \___/ \___/
  /_/ Galaxy at the Speed of Light
""")
    if os.path.exists(config.global_config_path()):
        info("Your parsec configuration already exists. Please edit it instead: %s" % config.global_config_path())
        return 0

    while True:
        galaxy_url = click.prompt("Please entry your Galaxy's URL")
        galaxy_key = click.prompt("Please entry your Galaxy API Key")
        info("Testing connection...")
        try:
            gi = galaxy.GalaxyInstance(galaxy_url, galaxy_key)
            if 'version_major' in gi.config.get_config():
                # Ok, success
                info("Ok! Everything looks good.")
                break
            else:
                warn("Error, we could not access the configuration data for your instance.")
                should_break = click.prompt("Continue despite inability to contact this Galaxy Instance? [y/n]")
                if should_break in ('Y', 'y'):
                    break
        except Exception as e:
            warn("Error, we could not access the configuration data for your instance.")
            should_break = click.prompt("Continue despite inability to contact this Galaxy Instance? [y/n]")
            if should_break in ('Y', 'y'):
                break

    config_path = config.global_config_path()
    if os.path.exists(config_path):
        warn("File %s already exists, refusing to overwrite." % config_path)
        return -1
    with open(config_path, "w") as f:
        f.write(
            CONFIG_TEMPLATE % {
                'key': galaxy_key,
                'url': galaxy_url,
            })
        info(SUCCESS_MESSAGE)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('create_history_tag')
@click.argument("history_id", type=str)
@click.argument("tag", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, history_id, tag):
    """Create history tag
    """
    return ctx.gi.histories.create_history_tag(history_id, tag)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('get_most_recently_used_history')


@pass_context
@bioblend_exception
@dict_output
def cli(ctx):
    """Returns the current user's most recently used history (not deleted).
    """
    return ctx.gi.histories.get_most_recently_used_history()



from __future__ import absolute_import
import os
import yaml

DEFAULT_CONFIG = {
}


def global_config_path():
    config_path = os.environ.get(
        "PARSEC_GLOBAL_CONFIG_PATH",
        "~/.parsec.yml"
    )
    config_path = os.path.expanduser(config_path)
    return config_path


def read_global_config():
    config_path = global_config_path()
    if not os.path.exists(config_path):
        return DEFAULT_CONFIG

    with open(config_path) as f:
        return yaml.load(f)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('show_role')
@click.argument("role_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, role_id):
    """Display information on a single role
    """
    return ctx.gi.roles.show_role(role_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('show_folder')
@click.argument("library_id", type=str)
@click.argument("folder_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, library_id, folder_id):
    """Get details about a given folder. The required ``folder_id`` can be obtained from the folder's library content details.
    """
    return ctx.gi.libraries.show_folder(library_id, folder_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('delete_library')
@click.argument("library_id", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, library_id):
    """Delete a data library.
    """
    return ctx.gi.libraries.delete_library(library_id)



import click
from parsec.cli import pass_context, json_loads
from parsec.decorators import bioblend_exception, dict_output

@click.command('create_remote_user')
@click.argument("user_email", type=str)


@pass_context
@bioblend_exception
@dict_output
def cli(ctx, user_email):
    """Create a new Galaxy remote user.
    """
    return ctx.gi.users.create_remote_user(user_email)
